@@ -193,7 +193,7 @@ class PipedZookeeperClient(object, service.Service):
                             except zookeeper.ZooKeeperException as zke:
                                 pass
 
-                            if current_state == zookeeper.CONNECTED_STATE:
+                            if not current_state == zookeeper.CONNECTED_STATE:
                                 logger.info('ZooKeeper client was unable to reach the connected state. Was in [{0}]'.format(client.STATE_NAME_MAPPING.get(current_state, 'unknwown')))
                                 current_client.close()
                                 if self._current_client == current_client:
